@@ -235,7 +235,6 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         if (aout != null)
             mp.setAudioOutput(aout);
         mp.getVLCVout().addCallback(this);
-
         return mp;
     }
 
@@ -356,7 +355,12 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
             unregisterReceiver(mRemoteControlClientReceiver);
             mRemoteControlClientReceiver = null;
         }
-        mMediaPlayer.release();
+        VLCApplication.runBackground(new Runnable() {
+            @Override
+            public void run() {
+                mMediaPlayer.release();
+            }
+        });
     }
 
     @Override
@@ -989,17 +993,9 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         if (media != null) {
             saveMediaMeta();
             media.setEventListener(null);
-            mMediaPlayer.setEventListener(null);
-            final MediaPlayer mp = mMediaPlayer;
-            VLCApplication.runBackground(new Runnable() {
-                @Override
-                public void run() {
-                    mp.stop();
-                    mp.setMedia(null);
-                }
-            });
             media.release();
         }
+        restartMediaPlayer();
         mMediaList.removeEventListener(mListEventListener);
         mPrevious.clear();
         mHandler.removeMessages(SHOW_PROGRESS);
@@ -1079,7 +1075,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         }
     }
 
-    private boolean isValidIndex(int position) {
+    public boolean isValidIndex(int position) {
         return position >= 0 && position < mMediaList.size();
     }
 
@@ -1214,7 +1210,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         @Override
         public void onPlayFromSearch(final String query, final Bundle extras) {
             if (!mMedialibrary.isInitiated()) {
-                startService(new Intent(MediaParsingService.ACTION_INIT, null, PlaybackService.this, MediaParsingService.class));
+                Util.startService(PlaybackService.this, new Intent(MediaParsingService.ACTION_INIT, null, PlaybackService.this, MediaParsingService.class));
                 final BroadcastReceiver libraryReadyReceiver = new BroadcastReceiver() {
                     @Override
                     public void onReceive(Context context, Intent intent) {
@@ -1538,7 +1534,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                 }
             };
             lbm.registerReceiver(mLibraryReceiver, new IntentFilter(VLCApplication.ACTION_MEDIALIBRARY_READY));
-            startService(new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
+            Util.startService(PlaybackService.this, new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
         }
     }
 
@@ -2497,7 +2493,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     }
 
     public void restartMediaPlayer() {
-        stop();
+        mMediaPlayer.setEventListener(null);
         final MediaPlayer mp = mMediaPlayer;
         VLCApplication.runBackground(new Runnable() {
             @Override
@@ -2563,8 +2559,9 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         public void connect() {
             if (mBound)
                 throw new IllegalStateException("already connected");
-            startService(mContext);
-            mBound = mContext.bindService(getServiceIntent(mContext), mServiceConnection, BIND_AUTO_CREATE);
+            final Intent serviceIntent = getServiceIntent(mContext);
+            mContext.startService(serviceIntent);
+            mBound = mContext.bindService(serviceIntent, mServiceConnection, BIND_AUTO_CREATE);
         }
 
         @MainThread
@@ -2596,7 +2593,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     public void onLoadChildren(@NonNull final String parentId, @NonNull final Result<List<MediaBrowserCompat.MediaItem>> result) {
         result.detach();
         if (!mMLInitializing && !mMedialibrary.isInitiated() && BrowserProvider.ID_ROOT.equals(parentId)) {
-            startService(new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
+            Util.startService(PlaybackService.this, new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
             mMLInitializing = true;
         }
         VLCApplication.runBackground(new Runnable() {
